const version = '1.0.0'

const create_config = (options = {}) => {
  const {
    id: sheet_id,
    field_prefix = 'clerk-field',
    label_prefix = 'clerk-label',
  } = options.stylesheet || {}

  const {
    id: field_id = 'email',
    class: field_class_name,
    extra_classes: field_extra_classes,
  } = options.field || {}

  const { class: label_class_name, extra_classes: label_extra_classes } =
    options.label || {}
  const { class: timer_class_name, name: timer_name = 'timer' } =
    options.timer || {}
  const { class: version_class_name, name: version_name = 'version' } =
    options.version || {}

  const honeypot_field_class_name =
    field_class_name || `${field_prefix}__${field_id}`
  const honeypot_label_class_name =
    label_class_name || `${label_prefix}__${field_id}`
  const honeypot_timer_class_name =
    timer_class_name || `${field_prefix}__${timer_name}`
  const honeypot_version_class_name =
    version_class_name || `${field_prefix}__${version_name}`

  return {
    style: {
      id: sheet_id,
      field_prefix: field_prefix,
      label_prefix: label_prefix,
      field_class_name: honeypot_field_class_name,
      label_class_name: honeypot_label_class_name,
    },
    honeypot: {
      field: {
        id: field_id,
        type: 'text',
        name: 'email',
        class_name: honeypot_field_class_name,
        extra_classes: field_extra_classes,
      },
      label: {
        for_id: field_id,
        class_name: honeypot_label_class_name,
        extra_classes: label_extra_classes,
      },
      timer: {
        class_name: honeypot_timer_class_name,
        name: timer_name,
      },
      version: {
        version,
        class_name: honeypot_version_class_name,
        name: version_name,
      },
    },
  }
}

export default create_config
