const version = '1.0.0'
import { obfuscate_string } from './string_tools'
import {
  create_honeypot_label,
  create_honeypot_field,
  create_timer_field,
  create_version_field,
} from './fields'
import create_config from './config'
import StyleSheet from './StyleSheet'

class Clerk {
  constructor(form, options = {}) {
    this.version = version
    this.loaded_at = new Date()
    this.form = form

    this.config = create_config(options)

    this.append_stylesheet()
    this.obfuscate_field_names()
    this.append_honeypot_fields()
    this.append_timer_field()
    this.append_version_field()
    this.form.addEventListener('submit', this.on_submit.bind(this))
  }

  append_stylesheet() {
    const stylesheet = new StyleSheet(this.config.style.id)

    stylesheet.add_rule(
      `.${this.config.honeypot.field.class_name}`,
      `
        position: absolute;
        right: 2000px;
      `
    )
    stylesheet.add_rule(
      `.${this.config.honeypot.label.class_name}`,
      `
        position: absolute;
        right: 2000px;
      `
    )
  }

  obfuscate_field_names() {
    const fields = Array.from(
      this.form.querySelectorAll('input:not([type=submit]), select, textarea')
    )
    fields.forEach((field) => {
      const id_or_name = field.id || field.name
      if (!id_or_name) {
        console.warn('Found field without name:', field)
        return
      }

      const label = this.form.querySelector(`label[for=${id_or_name}]`)
      if (label) {
        label.classList.add(`${this.config.style.label_prefix}__${id_or_name}`)
      }
      field.classList.add(`${this.config.style.field_prefix}__${id_or_name}`)
      field.name = obfuscate_string(field.name)
    })
  }

  append_honeypot_fields() {
    const label = create_honeypot_label(this.config.honeypot.label)
    const field = create_honeypot_field(this.config.honeypot.field)

    this.form.appendChild(label)
    this.form.appendChild(field)
  }

  append_timer_field() {
    this.timer_field = create_timer_field(this.config.honeypot.timer)
    this.form.appendChild(this.timer_field)
  }

  append_version_field() {
    this.version_field = create_version_field(this.config.honeypot.version)
    this.form.appendChild(this.version_field)
  }

  active_for() {
    return new Date() - this.loaded_at
  }

  on_submit(event) {
    console.log('Clerk onsubmit')
    this.timer_field.value = this.active_for()
    this.version_field.value = this.version
  }
}

export default Clerk
